@@ -1,36 +1,23 @@
 package Crypt::SSLeay;
 
 use strict;
-use vars '$VERSION';
-$VERSION = '0.65_15';
+use vars qw( @ISA $VERSION $XS_VERSION );
+$XS_VERSION = $VERSION = '0.73_03';
+$VERSION = eval $VERSION;
+
+use Bytes::Random::Secure;
 
 eval {
     require XSLoader;
-    XSLoader::load('Crypt::SSLeay', $VERSION);
+    XSLoader::load('Crypt::SSLeay', $XS_VERSION);
     1;
 }
 or do {
     require DynaLoader;
-    use vars '@ISA'; # not really locally scoped, it just looks that way
     @ISA = qw(DynaLoader);
-    bootstrap Crypt::SSLeay $VERSION;
+    bootstrap Crypt::SSLeay;
 };
 
-use vars qw(%CIPHERS);
-%CIPHERS = (
-   'NULL-MD5'     => "No encryption with a MD5 MAC",
-   'RC4-MD5'      => "128 bit RC4 encryption with a MD5 MAC",
-   'EXP-RC4-MD5'  => "40 bit RC4 encryption with a MD5 MAC",
-   'RC2-CBC-MD5'  => "128 bit RC2 encryption with a MD5 MAC",
-   'EXP-RC2-CBC-MD5' => "40 bit RC2 encryption with a MD5 MAC",
-   'IDEA-CBC-MD5' => "128 bit IDEA encryption with a MD5 MAC",
-   'DES-CBC-MD5'  => "56 bit DES encryption with a MD5 MAC",
-   'DES-CBC-SHA'  => "56 bit DES encryption with a SHA MAC",
-   'DES-CBC3-MD5' => "192 bit EDE3 DES encryption with a MD5 MAC",
-   'DES-CBC3-SHA' => "192 bit EDE3 DES encryption with a SHA MAC",
-   'DES-CFB-M1'   => "56 bit CFB64 DES encryption with a one byte MD5 MAC",
-);
-
 use Crypt::SSLeay::X509;
 
 # A xsupp bug made this necessary
@@ -48,7 +35,7 @@ Crypt::SSLeay - OpenSSL support for LWP
 
 =head1 HEARTBLEED WARNING
 
-C<make test> B<WILL FAIL> if your OpenSSL is vulnerable to the L<Heartbleed Bug|https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2014-0160>. You can, of course, force install the module but you will be doing so aware of the fact that your system is vulnerable to an extremely serious bug.
+C<perl Makefile.PL> will display a warning if it thinks your OpenSSL might be vulnerable to the  L<Heartbleed Bug|https://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2014-0160>. You can, of course, go ahead and install the module, but you should be aware that your system might be exposed to an extremely serious vulnerability. This is just a heuristic based on the version reported by OpenSSL. It is entirely possible that your distrbution actually pushed a patched library, so if you have concerns, you should investigate further.
 
 =head1 SYNOPSIS
 
