@@ -2,18 +2,23 @@ package Net::SSL;
 
 use strict;
 use MIME::Base64;
-use Socket;
-use Carp;
+use Socket qw(:DEFAULT :crlf);
+use Carp qw( croak );
 
-use vars qw(@ISA $VERSION $NEW_ARGS);
-$VERSION = '2.85';
+use vars qw(@ISA $VERSION);
+$VERSION = '2.88';
+$VERSION = eval $VERSION;
 
-require IO::Socket;
-@ISA=qw(IO::Socket::INET);
+BEGIN {
+    if (require IO::Socket::IP) {
+        @ISA = qw( IO::Socket::IP );
+    }
+    else {
+        require IO::Socket;
+        @ISA = qw( IO::Socket::INET );
+    }
+}
 
-my %REAL; # private to this package only
-my $DEFAULT_VERSION = '23';
-my $CRLF = "\015\012";
 my $SEND_USERAGENT_TO_PROXY = 0;
 
 require Crypt::SSLeay;
@@ -29,57 +34,45 @@ sub _alarm_set {
 }
 
 sub new {
-    my($class, %arg) = @_;
-    local $NEW_ARGS = \%arg;
-    $class->SUPER::new(%arg);
+    my $class = shift;
+    $class->SUPER::new(@_);
 }
 
 sub DESTROY {
     my $self = shift;
-    delete $REAL{$self};
-    local $@;
-    eval { $self->SUPER::DESTROY; };
+    local *@;
+    eval { $self->SUPER::DESTROY };
+    return;
 }
 
 sub configure {
-    my($self, $arg) = @_;
-    my $ssl_version = delete $arg->{SSL_Version} ||
-      $ENV{HTTPS_VERSION} || $DEFAULT_VERSION;
+    my $self = shift;
+    my $arg = shift;
+
     my $ssl_debug = delete $arg->{SSL_Debug} || $ENV{HTTPS_DEBUG} || 0;
 
-    my $ctx = delete $arg->{SSL_Context} || _default_context($ssl_version);
+    my $ctx = delete $arg->{SSL_Context} || _default_context();
 
     *$self->{ssl_ctx} = $ctx;
-    *$self->{ssl_version} = $ssl_version;
     *$self->{ssl_debug} = $ssl_debug;
     *$self->{ssl_arg} = $arg;
     *$self->{ssl_peer_addr} = $arg->{PeerAddr};
     *$self->{ssl_peer_port} = $arg->{PeerPort};
-    *$self->{ssl_new_arg} = $NEW_ARGS;
     *$self->{ssl_peer_verify} = 0;
 
-    ## Crypt::SSLeay must also aware the SSL Proxy before calling
-    ## $socket->configure($args). Because the $sock->configure() will
-    ## die when failed to resolve the destination server IP address,
-    ## whether the SSL proxy is used or not!
-    ## - dqbai, 2003-05-10
     if (my $proxy = $self->proxy) {
         ($arg->{PeerAddr}, $arg->{PeerPort}) = split(':',$proxy);
-        $arg->{PeerPort} || croak("no port given for proxy server $proxy");
+        unless ( $arg->{PeerPort} ) {
+            croak("no port given for proxy server $proxy");
+        }
     }
 
     $self->SUPER::configure($arg);
 }
 
-# override to make sure there is really a timeout
-sub timeout {
-    shift->SUPER::timeout || 60;
-}
+sub timeout { shift->SUPER::timeout || 60 }
 
-sub blocking {
-    my $self = shift;
-    $self->SUPER::blocking(@_);
-}
+sub blocking { shift->SUPER::blocking(@_) }
 
 sub connect {
     my $self = shift;
@@ -87,13 +80,13 @@ sub connect {
     # configure certs on connect() time, so we can throw an undef
     # and have LWP understand the error
     eval { $self->configure_certs() };
-    if($@) {
+    if ($@) {
         $@ = "configure certs failed: $@; $!";
         $self->die_with_error($@);
     }
 
     # finished, update set_verify status
-    if(my $rv = *$self->{ssl_ctx}->set_verify()) {
+    if (my $rv = *$self->{ssl_ctx}->set_verify()) {
         *$self->{ssl_peer_verify} = $rv;
     }
 
@@ -106,7 +99,8 @@ sub connect {
         }
     }
     else {
-        *$self->{io_socket_peername}=@_ == 1 ? $_[0] : IO::Socket::sockaddr_in(@_);
+        *$self->{io_socket_peername} = (@_ == 1) ? $_[0]
+                                     : IO::Socket::sockaddr_in(@_);
         if(!$self->SUPER::connect(@_)) {
             # better to die than return here
             $@ = "Connect failed: $@; $!";
@@ -125,45 +119,27 @@ sub connect {
         $ssl->set_tlsext_host_name(*$self->{ssl_peer_addr});
 
     eval {
-        local $SIG{ALRM} = sub { $self->die_with_error("SSL connect timeout") };
-        # timeout / 2 because we have 3 possible connects here
-        _alarm_set($self->timeout / 2);
+        local $SIG{ALRM} = sub {
+            $self->die_with_error("SSL connect timeout")
+        };
+        _alarm_set($self->timeout);
 
         my $rv;
         {
             local $SIG{PIPE} = \&die;
-            $rv = eval { $ssl->connect; };
+            $rv = eval { $ssl->connect };
         }
         if (not defined $rv or $rv <= 0) {
             _alarm_set(0);
             $ssl = undef;
-            # See RT #59312
-            my %args = (%$arg, %$new_arg);
-            if(*$self->{ssl_version} == 23) {
-                $args{SSL_Version} = 3;
-                # the new connect might itself be overridden with a REAL SSL
-                my $new_ssl = Net::SSL->new(%args);
-                $REAL{$self} = $REAL{$new_ssl} || $new_ssl;
-                return $REAL{$self};
-            }
-            elsif(*$self->{ssl_version} == 3) {
-                # $self->die_with_error("SSL negotiation failed");
-                $args{SSL_Version} = 2;
-                my $new_ssl = Net::SSL->new(%args);
-                $REAL{$self} = $new_ssl;
-                return $new_ssl;
-            }
-			else {
-                # don't die, but do set $@, and return undef
-                eval { $self->die_with_error("SSL negotiation failed") };
-                croak($@);
-            }
+            eval { $self->die_with_error("SSL negotiation failed") };
+            croak($@);
         }
         _alarm_set(0);
     };
 
     # odd error in eval {} block, maybe alarm outside the evals
-    if($@) {
+    if ($@) {
         $@ = "$@; $!";
         croak($@);
     }
@@ -176,37 +152,31 @@ sub connect {
 # Delegate these calls to the Crypt::SSLeay::Conn object
 sub get_peer_certificate {
     my $self = shift;
-    $self = $REAL{$self} || $self;
     *$self->{ssl_ssl}->get_peer_certificate(@_);
 }
 
 sub get_peer_verify {
     my $self = shift;
-    $self = $REAL{$self} || $self;
     *$self->{ssl_peer_verify};
 }
 
 sub get_shared_ciphers {
     my $self = shift;
-    $self = $REAL{$self} || $self;
     *$self->{ssl_ssl}->get_shared_ciphers(@_);
 }
 
 sub get_cipher {
     my $self = shift;
-    $self = $REAL{$self} || $self;
     *$self->{ssl_ssl}->get_cipher(@_);
 }
 
 sub pending {
     my $self = shift;
-    $self = $REAL{$self} || $self;
     *$self->{ssl_ssl}->pending(@_);
 }
 
 sub ssl_context {
     my $self = shift;
-    $self = $REAL{$self} || $self;
     *$self->{ssl_ctx};
 }
 
@@ -223,7 +193,6 @@ sub die_with_error {
 
 sub read {
     my $self = shift;
-    $self = $REAL{$self} || $self;
 
     local $SIG{__DIE__} = \&Carp::confess;
     local $SIG{ALRM} = sub { $self->die_with_error("SSL read timeout") };
@@ -238,7 +207,6 @@ sub read {
 
 sub write {
     my $self = shift;
-    $self = $REAL{$self} || $self;
     my $n = *$self->{ssl_ssl}->write(@_);
     $self->die_with_error("write failed") if !defined $n;
     $n;
@@ -249,7 +217,6 @@ sub write {
 
 sub print {
     my $self = shift;
-    $self = $REAL{$self} || $self;
     # should we care about $, and $\??
     # I think it is too expensive...
     $self->write(join("", @_));
@@ -257,14 +224,12 @@ sub print {
 
 sub printf {
     my $self = shift;
-    $self = $REAL{$self} || $self;
     my $fmt = shift;
     $self->write(sprintf($fmt, @_));
 }
 
 sub getchunk {
     my $self = shift;
-    $self = $REAL{$self} || $self;
     my $buf = '';  # warnings
     my $n = $self->read($buf, 32768);
     return unless defined $n;
@@ -275,8 +240,7 @@ sub getchunk {
 # so that does not really matter.
 sub getline {
     my $self = shift;
-    $self = $REAL{$self} || $self;
-    my $val="";
+    my $val = "";
     my $buf;
     do {
         $self->SUPER::recv($buf, 1);
@@ -384,7 +348,7 @@ sub proxy_connect_helper {
     # better) may actually make this problem go away, but either way,
     # there is no good reason to use \d when checking for 0-9
 
-    while ($header !~ m{HTTP/[0-9][.][0-9]\s+200\s+.*$CRLF$CRLF}) {
+    while ($header !~ m{HTTP/[0-9][.][0-9]\s+200\s+.*$CRLF$CRLF}s) {
         $timeout = $self->timeout(5) unless length $header;
         my $n = $self->SUPER::sysread($header, 8192, length $header);
         last if $n <= 0;
